package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.HlDayDetail;
import com.jjt.biz.service.IHlDayDetailService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 日健康扣分明细Controller
 *
 * @author jjt
 * @date 2024-08-29
 */
@Api(tags="日健康扣分明细")
@RestController
@RequestMapping("/hl/hdd")
public class HlDayDetailController extends BaseController
{
    @Resource
    private IHlDayDetailService hlDayDetailService;

    /**
     * 查询日健康扣分明细列表
     */
    @ApiOperation("查询日健康扣分明细列表")
    @PreAuthorize("@ss.hasPermi('hl:hdd:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlDayDetail hlDayDetail)
    {
        startPage();
        List<HlDayDetail> list = hlDayDetailService.selectHlDayDetailList(hlDayDetail);
        return getDataTable(list);
    }

    /**
     * 导出日健康扣分明细列表
     */
    @ApiOperation("导出日健康扣分明细列表")
    @PreAuthorize("@ss.hasPermi('hl:hdd:export')")
    @Log(title = "日健康扣分明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlDayDetail hlDayDetail)
    {
        List<HlDayDetail> list = hlDayDetailService.selectHlDayDetailList(hlDayDetail);
        ExcelUtil<HlDayDetail> util = new ExcelUtil<HlDayDetail>(HlDayDetail.class);
        util.exportExcel(response, list, "日健康扣分明细数据");
    }

    /**
     * 获取日健康扣分明细详细信息
     */
    @ApiOperation("获取日健康扣分明细详细信息")
    @PreAuthorize("@ss.hasPermi('hl:hdd:query')")
    @GetMapping(value = "/{dayDetailId}")
    public AjaxResult getInfo(@PathVariable("dayDetailId") Long dayDetailId)
    {
        return success(hlDayDetailService.selectHlDayDetailByDayDetailId(dayDetailId));
    }

    /**
     * 新增日健康扣分明细
     */
    @ApiOperation("新增日健康扣分明细")
    @PreAuthorize("@ss.hasPermi('hl:hdd:add')")
    @Log(title = "日健康扣分明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlDayDetail hlDayDetail)
    {
        return toAjax(hlDayDetailService.insertHlDayDetail(hlDayDetail));
    }

    /**
     * 修改日健康扣分明细
     */
    @ApiOperation("修改日健康扣分明细")
    @PreAuthorize("@ss.hasPermi('hl:hdd:edit')")
    @Log(title = "日健康扣分明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HlDayDetail hlDayDetail)
    {
        return toAjax(hlDayDetailService.updateHlDayDetail(hlDayDetail));
    }

    /**
     * 删除日健康扣分明细
     */
    @ApiOperation("删除日健康扣分明细")
    @PreAuthorize("@ss.hasPermi('hl:hdd:remove')")
    @Log(title = "日健康扣分明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{dayDetailIds}")
    public AjaxResult remove(@PathVariable Long[] dayDetailIds)
    {
        return toAjax(hlDayDetailService.deleteHlDayDetailByDayDetailIds(dayDetailIds));
    }
}
