package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.HlMetricsRela;
import com.jjt.biz.service.IHlMetricsRelaService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 健康指标关系Controller
 *
 * @author jjt
 * @date 2024-09-01
 */
@Api(tags="健康指标关系")
@RestController
@RequestMapping("/hl/rela")
public class HlMetricsRelaController extends BaseController
{
    @Resource
    private IHlMetricsRelaService hlMetricsRelaService;

    /**
     * 查询健康指标关系列表
     */
    @ApiOperation("查询健康指标关系列表")
    @PreAuthorize("@ss.hasPermi('hl:rela:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlMetricsRela hlMetricsRela)
    {
        startPage();
        List<HlMetricsRela> list = hlMetricsRelaService.selectHlMetricsRelaList(hlMetricsRela);
        return getDataTable(list);
    }

    /**
     * 导出健康指标关系列表
     */
    @ApiOperation("导出健康指标关系列表")
    @PreAuthorize("@ss.hasPermi('hl:rela:export')")
    @Log(title = "健康指标关系", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlMetricsRela hlMetricsRela)
    {
        List<HlMetricsRela> list = hlMetricsRelaService.selectHlMetricsRelaList(hlMetricsRela);
        ExcelUtil<HlMetricsRela> util = new ExcelUtil<HlMetricsRela>(HlMetricsRela.class);
        util.exportExcel(response, list, "健康指标关系数据");
    }

    /**
     * 获取健康指标关系详细信息
     */
    @ApiOperation("获取健康指标关系详细信息")
    @PreAuthorize("@ss.hasPermi('hl:rela:query')")
    @GetMapping(value = "/{relaId}")
    public AjaxResult getInfo(@PathVariable("relaId") Long relaId)
    {
        return success(hlMetricsRelaService.selectHlMetricsRelaByRelaId(relaId));
    }

    /**
     * 新增健康指标关系
     */
    @ApiOperation("新增健康指标关系")
    @PreAuthorize("@ss.hasPermi('hl:rela:add')")
    @Log(title = "健康指标关系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlMetricsRela hlMetricsRela)
    {
        return toAjax(hlMetricsRelaService.insertHlMetricsRela(hlMetricsRela));
    }

    /**
     * 修改健康指标关系
     */
    @ApiOperation("修改健康指标关系")
    @PreAuthorize("@ss.hasPermi('hl:rela:edit')")
    @Log(title = "健康指标关系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HlMetricsRela hlMetricsRela)
    {
        return toAjax(hlMetricsRelaService.updateHlMetricsRela(hlMetricsRela));
    }

    /**
     * 删除健康指标关系
     */
    @ApiOperation("删除健康指标关系")
    @PreAuthorize("@ss.hasPermi('hl:rela:remove')")
    @Log(title = "健康指标关系", businessType = BusinessType.DELETE)
	@DeleteMapping("/{relaIds}")
    public AjaxResult remove(@PathVariable Long[] relaIds)
    {
        return toAjax(hlMetricsRelaService.deleteHlMetricsRelaByRelaIds(relaIds));
    }
}
