package com.jjt.biz.controller;

import com.jjt.biz.domain.HlBase;
import com.jjt.biz.domain.HlScore;
import com.jjt.biz.domain.HlScoreDetail;
import com.jjt.biz.service.IHlBaseService;
import com.jjt.biz.service.IHlScoreDetailService;
import com.jjt.biz.service.IHlScoreService;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 健康度分数记录Controller
 *
 * @author jjt
 * @date 2024-08-29
 */
@Api(tags = "健康度分数记录")
@RestController
@RequestMapping("/hl/hlScore")
public class HlScoreController extends BaseController {
    @Resource
    private IHlScoreService hlScoreService;
    @Resource
    private IHlScoreDetailService scoreDetailService;
    @Resource
    private IHlBaseService baseService;

    @ApiOperation("根据模型ID查询健康度得分")
    @GetMapping("/list/{modelId}")
    public TableDataInfo list(@PathVariable("modelId") Long modelId) {
        startPage();
        HlScore hlScore = new HlScore();
        hlScore.setModelId(modelId);
        List<HlScore> list = hlScoreService.selectHlScoreList(hlScore);
        return getDataTable(list);
    }

    @ApiOperation("健康度得分明细")
    @GetMapping(value = "/{hlScoreId}")
    public AjaxResult getInfo(@PathVariable("hlScoreId") Long hlScoreId) {
        HlScore hlScore = hlScoreService.selectHlScoreByHlScoreId(hlScoreId);
        HlBase base = baseService.selectHlBaseByModelId(hlScore.getModelId());
        HlScoreDetail query = new HlScoreDetail();
        query.setHlScoreId(hlScoreId);
        List<HlScoreDetail> detailList = scoreDetailService.selectHlScoreDetailList(query);

        Map<String, BigDecimal> map = detailList.stream().collect(Collectors.toMap(HlScoreDetail::getHlCode, HlScoreDetail::getHlScore));
        base.getHlClassList().forEach(hlClass -> {
            if (map.containsKey(hlClass.getClassCode())) {
                hlClass.setCurrScore(map.get(hlClass.getClassCode()).floatValue());
            }

            hlClass.getHlObjList().forEach(hlObj -> {
                if (map.containsKey(hlObj.getHlObjCode())) {
                    hlObj.setCurrScore(map.get(hlObj.getHlObjCode()).floatValue());
                }

                hlObj.getHlDetailList().forEach(hlDetail -> {
                    if (map.containsKey(hlDetail.getHlDetailCode())) {
                        hlDetail.setCurrScore(map.get(hlDetail.getHlDetailCode()).floatValue());
                    }
                });
            });

        });

        return success(base);
    }

    /**
     * 查询健康度分数记录列表
     */
    @ApiOperation("查询健康度分数记录列表")
    @PreAuthorize("@ss.hasPermi('hl:hlScore:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlScore hlScore) {
        startPage();
        List<HlScore> list = hlScoreService.selectHlScoreList(hlScore);
        return getDataTable(list);
    }
//
//    /**
//     * 导出健康度分数记录列表
//     */
//    @ApiOperation("导出健康度分数记录列表")
//    @PreAuthorize("@ss.hasPermi('hl:hlScore:export')")
//    @Log(title = "健康度分数记录", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, HlScore hlScore) {
//        List<HlScore> list = hlScoreService.selectHlScoreList(hlScore);
//        ExcelUtil<HlScore> util = new ExcelUtil<HlScore>(HlScore.class);
//        util.exportExcel(response, list, "健康度分数记录数据");
//    }

//    /**
//     * 新增健康度分数记录
//     */
//    @ApiOperation("新增健康度分数记录")
//    @PreAuthorize("@ss.hasPermi('hl:hlScore:add')")
//    @Log(title = "健康度分数记录", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody HlScore hlScore) {
//        return toAjax(hlScoreService.insertHlScore(hlScore));
//    }
//
//    /**
//     * 修改健康度分数记录
//     */
//    @ApiOperation("修改健康度分数记录")
//    @PreAuthorize("@ss.hasPermi('hl:hlScore:edit')")
//    @Log(title = "健康度分数记录", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody HlScore hlScore) {
//        return toAjax(hlScoreService.updateHlScore(hlScore));
//    }
//
//    /**
//     * 删除健康度分数记录
//     */
//    @ApiOperation("删除健康度分数记录")
//    @PreAuthorize("@ss.hasPermi('hl:hlScore:remove')")
//    @Log(title = "健康度分数记录", businessType = BusinessType.DELETE)
//    @DeleteMapping("/{hlScoreIds}")
//    public AjaxResult remove(@PathVariable Long[] hlScoreIds) {
//        return toAjax(hlScoreService.deleteHlScoreByHlScoreIds(hlScoreIds));
//    }
}
