package com.jjt.biz.controller;

import com.jjt.biz.domain.HlScoreDetail;
import com.jjt.biz.service.IHlScoreDetailService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 健康度扣分明细Controller
 *
 * @author jjt
 * @date 2024-08-29
 */
@Api(tags = "健康度扣分明细")
@RestController
@RequestMapping("/hl/hlScoreDetail")
public class HlScoreDetailController extends BaseController {
    @Resource
    private IHlScoreDetailService hlScoreDetailService;

    /**
     * 查询健康度扣分明细列表
     */
    @ApiOperation("查询健康度扣分明细列表")
    @PreAuthorize("@ss.hasPermi('hl:hlScoreDetail:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlScoreDetail hlScoreDetail) {
        startPage();
        List<HlScoreDetail> list = hlScoreDetailService.selectHlScoreDetailList(hlScoreDetail);
        return getDataTable(list);
    }

    /**
     * 导出健康度扣分明细列表
     */
    @ApiOperation("导出健康度扣分明细列表")
    @PreAuthorize("@ss.hasPermi('hl:hlScoreDetail:export')")
    @Log(title = "健康度扣分明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlScoreDetail hlScoreDetail) {
        List<HlScoreDetail> list = hlScoreDetailService.selectHlScoreDetailList(hlScoreDetail);
        ExcelUtil<HlScoreDetail> util = new ExcelUtil<HlScoreDetail>(HlScoreDetail.class);
        util.exportExcel(response, list, "健康度扣分明细数据");
    }

    /**
     * 获取健康度扣分明细详细信息
     */
    @ApiOperation("获取健康度扣分明细详细信息")
    @PreAuthorize("@ss.hasPermi('hl:hlScoreDetail:query')")
    @GetMapping(value = "/{hlScoreDetailId}")
    public AjaxResult getInfo(@PathVariable("hlScoreDetailId") Long hlScoreDetailId) {
        return success(hlScoreDetailService.selectHlScoreDetailByHlScoreDetailId(hlScoreDetailId));
    }

    /**
     * 新增健康度扣分明细
     */
    @ApiOperation("新增健康度扣分明细")
    @PreAuthorize("@ss.hasPermi('hl:hlScoreDetail:add')")
    @Log(title = "健康度扣分明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlScoreDetail hlScoreDetail) {
        return toAjax(hlScoreDetailService.insertHlScoreDetail(hlScoreDetail));
    }

    /**
     * 修改健康度扣分明细
     */
    @ApiOperation("修改健康度扣分明细")
    @PreAuthorize("@ss.hasPermi('hl:hlScoreDetail:edit')")
    @Log(title = "健康度扣分明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HlScoreDetail hlScoreDetail) {
        return toAjax(hlScoreDetailService.updateHlScoreDetail(hlScoreDetail));
    }

    /**
     * 删除健康度扣分明细
     */
    @ApiOperation("删除健康度扣分明细")
    @PreAuthorize("@ss.hasPermi('hl:hlScoreDetail:remove')")
    @Log(title = "健康度扣分明细", businessType = BusinessType.DELETE)
    @DeleteMapping("/{hlScoreDetailIds}")
    public AjaxResult remove(@PathVariable Long[] hlScoreDetailIds) {
        return toAjax(hlScoreDetailService.deleteHlScoreDetailByHlScoreDetailIds(hlScoreDetailIds));
    }
}
