package com.jjt.biz.service.impl;

import com.jjt.biz.domain.*;
import com.jjt.biz.mapper.HlBaseMapper;
import com.jjt.biz.service.*;
import com.jjt.common.utils.DateUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.ZoneId;
import java.util.*;
import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Collectors;

/**
 * 健康度配置基本Service业务层处理
 *
 * @author jjt
 * @date 2024-08-28
 */
@Service
public class HlBaseServiceImpl implements IHlBaseService {
    @Resource
    private HlBaseMapper hlBaseMapper;
    @Resource
    private IHlClassService classService;
    @Resource
    private IHlObjService objService;
    @Resource
    private IHlDetailService detailService;
    @Resource
    private JdbcTemplate jdbcTemplate;
    @Resource
    private IHlScoreService scoreService;
    @Resource
    private IHlScoreDetailService scoreDetailService;
    @Resource
    private IHlDayService dayService;
    @Resource
    private IHlDayDetailService dayDetailService;
    @Resource
    private IHlMetricsRelaService relaService;


    /**
     * 查询健康度配置基本
     *
     * @param hlBaseId 健康度配置基本主键
     * @return 健康度配置基本
     */
    @Override

    public HlBase selectHlBaseByHlBaseId(Long hlBaseId) {
        return hlBaseMapper.selectHlBaseByHlBaseId(hlBaseId);
    }

    /**
     * 根据模型ID查询
     *
     * @param modelId 健康度配置基本主键
     * @return 结果
     */
    @Override
    public HlBase selectHlBaseByModelId(Long modelId) {
        return hlBaseMapper.selectHlBaseByModelId(modelId);
    }

    /**
     * 查询健康度配置基本列表
     *
     * @param hlBase 健康度配置基本
     * @return 健康度配置基本
     */
    @Override
    public List<HlBase> selectHlBaseList(HlBase hlBase) {
        return hlBaseMapper.selectHlBaseList(hlBase);
    }

    /**
     * 新增健康度配置基本
     *
     * @param hlBase 健康度配置基本
     * @return 结果
     */
    @Override
    public int insertHlBase(HlBase hlBase) {
        hlBase.setCreateTime(DateUtils.getNowDate());
        return hlBaseMapper.insertHlBase(hlBase);
    }

    /**
     * 修改健康度配置基本
     *
     * @param hlBase 健康度配置基本
     * @return 结果
     */
    @Override
    public int updateHlBase(HlBase hlBase) {
        hlBase.setUpdateTime(DateUtils.getNowDate());
        return hlBaseMapper.updateHlBase(hlBase);
    }

    /**
     * 批量删除健康度配置基本
     *
     * @param hlBaseIds 需要删除的健康度配置基本主键
     * @return 结果
     */
    @Override
    public int deleteHlBaseByHlBaseIds(Long[] hlBaseIds) {
        return hlBaseMapper.deleteHlBaseByHlBaseIds(hlBaseIds);
    }

    /**
     * 删除健康度配置基本信息
     *
     * @param hlBaseId 健康度配置基本主键
     * @return 结果
     */
    @Override
    public int deleteHlBaseByHlBaseId(Long hlBaseId) {
        return hlBaseMapper.deleteHlBaseByHlBaseId(hlBaseId);
    }

    /**
     * 根据模型ID插入健康度数据
     *
     * @param modelId 模型ID
     */
    @Override
    public void insertHlBase4ModelId(Long modelId) {
        //如果没有数据，则复制基础数据到模型
        HlBase base = selectHlBaseByHlBaseId(1L);
        base.setHlBaseId(null);
        base.setModelId(modelId);
        insertHlBase(base);
        List<HlClass> classes = base.getHlClassList();
        HlBase finalBase = base;
        classes.forEach(cs -> {
            cs.setClassId(null);
            cs.setHlBaseId(finalBase.getHlBaseId());
            classService.insertHlClass(cs);
            List<HlObj> objs = cs.getHlObjList();
            objs.forEach(ob -> {
                ob.setClassId(cs.getClassId());
                ob.setHlObjId(null);
                objService.insertHlObj(ob);
                List<HlDetail> details = ob.getHlDetailList();
                details.forEach(d -> {
                    d.setHlObjId(ob.getHlObjId());
                    d.setHlDetailId(null);
                    detailService.insertHlDetail(d);
                });
            });
        });
    }


    /**
     * 根据模型ID删除健康度数据
     *
     * @param modelId 模型ID
     */
    @Override
    public void deleteHlBase4ModelId(Long modelId) {
        if (modelId == -1) {
            return;
        }
        try {
            // 开始事务
            jdbcTemplate.execute("BEGIN");

            // 执行删除语句
            jdbcTemplate.update("DELETE FROM hl_detail WHERE HL_OBJ_ID IN (SELECT HL_OBJ_ID FROM hl_obj WHERE CLASS_ID IN (SELECT CLASS_ID FROM hl_class WHERE hl_base_id IN (SELECT hl_base_id FROM hl_base WHERE model_id = ?)))", modelId);
            jdbcTemplate.update("DELETE FROM hl_obj WHERE CLASS_ID IN (SELECT CLASS_ID FROM hl_class WHERE hl_base_id IN (SELECT hl_base_id FROM hl_base WHERE model_id = ?))", modelId);
            jdbcTemplate.update("DELETE FROM hl_class WHERE hl_base_id IN (SELECT hl_base_id FROM hl_base WHERE model_id = ?)", modelId);
            jdbcTemplate.update("DELETE FROM hl_base WHERE model_id = ?", modelId);

            // 提交事务
            jdbcTemplate.execute("COMMIT");
        } catch (Exception e) {
            // 回滚事务
            jdbcTemplate.execute("ROLLBACK");
            throw new RuntimeException(e);
        }
    }

    /**
     * 健康度评分
     */
    @Override
    public void score() {
        Map<String, Long> relaMap = relaService.selectHlMetricsRelaList(new HlMetricsRela()).stream()
                .collect(Collectors.toMap(HlMetricsRela::getHlCode, HlMetricsRela::getMetricsId));
        List<HlBase> list = selectHlBaseList(new HlBase());
        list.forEach(base -> {
            if (base.getModelId() != -1) {
                HlScore score = new HlScore();
                score.setModelId(base.getModelId());
                scoreService.insertHlScore(score);
                List<HlClass> classes = base.getHlClassList();
                AtomicReference<BigDecimal> total = new AtomicReference<>(new BigDecimal(0));
                classes.forEach(cs -> {
                    HlScoreDetail csDetail = new HlScoreDetail();
                    csDetail.setHlScoreId(score.getHlScoreId());
                    csDetail.setHlType("CLASS");
                    csDetail.setHlCode(cs.getClassCode());
                    List<HlObj> objs = cs.getHlObjList();
                    AtomicReference<BigDecimal> scc = new AtomicReference<>(new BigDecimal(0));
                    objs.forEach(ob -> {
                        List<HlDetail> details = ob.getHlDetailList();
                        HlScoreDetail obDetail = new HlScoreDetail();
                        obDetail.setHlScoreId(score.getHlScoreId());
                        obDetail.setHlType("OBJ");
                        obDetail.setHlCode(ob.getHlObjCode());
                        AtomicReference<BigDecimal> sc = new AtomicReference<>(new BigDecimal(0));
                        if ("LINK".equals(ob.getHlObjCode())) {
                            details.forEach(d -> {
                                HlScoreDetail scoreDetail = new HlScoreDetail();
                                scoreDetail.setHlScoreId(score.getHlScoreId());
                                scoreDetail.setHlType("DETAIL");
                                scoreDetail.setHlCode(d.getHlDetailCode());
                                switch (d.getHlDetailCode()) {
                                    case "C01":
                                    case "C02":
                                    case "C03":
                                        BigDecimal dc = random(d.getHlDetailScore());
                                        scoreDetail.setHlScore(dc);
                                        sc.set(sc.get().add(dc));
                                        scoreDetailService.insertHlScoreDetail(scoreDetail);
                                        break;
                                    default:
                                        break;
                                }
                            });
                        } else {
                            sc.set(random(ob.getHlObjScore()));
                        }
                        obDetail.setHlScore(sc.get());
                        scoreDetailService.insertHlScoreDetail(obDetail);
                        scc.set(scc.get().add(obDetail.getHlScore()));
                    });
                    csDetail.setHlScore(scc.get());
                    scoreDetailService.insertHlScoreDetail(csDetail);
                    total.set(total.get().add(csDetail.getHlScore()));
                });
                score.setHlScore(total.get());
                scoreService.updateHlScore(score);
            }
        });
    }

    /**
     * 昨日健康度评分
     */
    @Override
    public void yesterday() {
        LocalDate localDate = LocalDate.now().minusDays(1);
        List<HlBase> list = selectHlBaseList(new HlBase());

        list.forEach(base -> {
            if (base.getModelId() != -1) {
                HlDay hlDay = new HlDay();
                hlDay.setModelId(base.getModelId());
                hlDay.setHlDate(Date.from(localDate.atStartOfDay(ZoneId.systemDefault()).toInstant()));
                dayService.insertHlDay(hlDay);
                List<HlClass> classes = base.getHlClassList();
                AtomicReference<BigDecimal> total = new AtomicReference<>(new BigDecimal(0));
                classes.forEach(cs -> {
                    HlDayDetail csDetail = new HlDayDetail();
                    csDetail.setDayId(hlDay.getDayId());
                    csDetail.setHlType("CLASS");
                    csDetail.setHlCode(cs.getClassCode());
                    List<HlObj> objs = cs.getHlObjList();
                    AtomicReference<BigDecimal> scc = new AtomicReference<>(new BigDecimal(0));
                    objs.forEach(ob -> {
                        List<HlDetail> details = ob.getHlDetailList();
                        HlDayDetail obDetail = new HlDayDetail();
                        obDetail.setDayId(hlDay.getDayId());
                        obDetail.setHlType("OBJ");
                        obDetail.setHlCode(ob.getHlObjCode());
                        AtomicReference<BigDecimal> sc = new AtomicReference<>(new BigDecimal(0));
                        if ("LINK".equals(ob.getHlObjCode())) {
                            details.forEach(d -> {
                                HlDayDetail scoreDetail = new HlDayDetail();
                                scoreDetail.setDayId(hlDay.getDayId());
                                scoreDetail.setHlType("DETAIL");
                                scoreDetail.setHlCode(d.getHlDetailCode());
                                switch (d.getHlDetailCode()) {
                                    case "C01":
                                    case "C02":
                                    case "C03":
                                        BigDecimal dc = random(d.getHlDetailScore());
                                        scoreDetail.setHlScore(dc);
                                        sc.set(sc.get().add(dc));
                                        dayDetailService.insertHlDayDetail(scoreDetail);
                                        break;
                                    default:
                                        break;
                                }
                            });
                        } else {
                            sc.set(random(ob.getHlObjScore()));
                        }
                        obDetail.setHlScore(sc.get());
                        dayDetailService.insertHlDayDetail(obDetail);
                        scc.set(scc.get().add(obDetail.getHlScore()));
                    });
                    csDetail.setHlScore(scc.get());
                    dayDetailService.insertHlDayDetail(csDetail);
                    total.set(total.get().add(csDetail.getHlScore()));
                });
                hlDay.setHlScore(total.get());
                dayService.updateHlDay(hlDay);
            }
        });
    }

    private BigDecimal random(Long s) {
        Random random = new Random();
        int randomNumber = random.nextInt(3);
        // 生01到3的随机数
        int v = s.intValue() - randomNumber;
        return BigDecimal.valueOf(v);
    }
}
