package com.jjt.biz.service.impl;

import java.util.List;
        import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;
import com.jjt.biz.mapper.HlScoreMapper;
import com.jjt.biz.domain.HlScore;
import com.jjt.biz.service.IHlScoreService;
import javax.annotation.Resource;

/**
 * 健康度分数记录Service业务层处理
 *
 * @author jjt
 * @date 2024-08-29
 */
@Service
public class HlScoreServiceImpl implements IHlScoreService {
    @Resource
    private HlScoreMapper hlScoreMapper;

    /**
     * 查询健康度分数记录
     *
     * @param hlScoreId 健康度分数记录主键
     * @return 健康度分数记录
     */
    @Override
    public HlScore selectHlScoreByHlScoreId(Long hlScoreId) {
        return hlScoreMapper.selectHlScoreByHlScoreId(hlScoreId);
    }

    /**
     * 查询健康度分数记录列表
     *
     * @param hlScore 健康度分数记录
     * @return 健康度分数记录
     */
    @Override
    public List<HlScore> selectHlScoreList(HlScore hlScore) {
        return hlScoreMapper.selectHlScoreList(hlScore);
    }

    /**
     * 新增健康度分数记录
     *
     * @param hlScore 健康度分数记录
     * @return 结果
     */
    @Override
    public int insertHlScore(HlScore hlScore) {
                hlScore.setCreateTime(DateUtils.getNowDate());
            return hlScoreMapper.insertHlScore(hlScore);
    }

    /**
     * 修改健康度分数记录
     *
     * @param hlScore 健康度分数记录
     * @return 结果
     */
    @Override
    public int updateHlScore(HlScore hlScore) {
                hlScore.setUpdateTime(DateUtils.getNowDate());
        return hlScoreMapper.updateHlScore(hlScore);
    }

    /**
     * 批量删除健康度分数记录
     *
     * @param hlScoreIds 需要删除的健康度分数记录主键
     * @return 结果
     */
    @Override
    public int deleteHlScoreByHlScoreIds(Long[] hlScoreIds) {
        return hlScoreMapper.deleteHlScoreByHlScoreIds(hlScoreIds);
    }

    /**
     * 删除健康度分数记录信息
     *
     * @param hlScoreId 健康度分数记录主键
     * @return 结果
     */
    @Override
    public int deleteHlScoreByHlScoreId(Long hlScoreId) {
        return hlScoreMapper.deleteHlScoreByHlScoreId(hlScoreId);
    }
}
